@@ -1,6 +1,6 @@
 from PyQt6 import QtCore, QtGui, QtWidgets
 from PyQt6.QtCore import QObject
-import Plot, DataTIC
+from ticsummary import Plot, DataTIC
 
 
 class WaveScintillators(Plot.Ui_Plot):
