@@ -1,7 +1,6 @@
 from PyQt6 import QtCore, QtGui, QtWidgets   
 from ticsummary import MainWindow, ConnectionConfigurationDialog, DatabaseMYSQL, Plot
 
-
 class EntryPoint:
     sqlParameters:DatabaseMYSQL.ParameterConnection
     profilePlot1: Plot
@@ -13,8 +12,9 @@ class EntryPoint:
         
         self.mainWindow.show()
         sys.exit(app.exec())
+
+ 
     
-    
-if __name__ == '__main__':
+def startup():
     entryPoint = EntryPoint()
     entryPoint.run()
\ No newline at end of file
